@@ -643,6 +643,13 @@ impl Statement {
         &self.subject
     }
 
+    ///
+    /// Set the value of this statement's subject.
+    ///
+    pub fn set_subject(&mut self, subject: SubjectNodeRef) {
+        self.subject = subject;
+    }
+
     ///
     /// Return the predicate of this statement.
     ///
@@ -650,6 +657,13 @@ impl Statement {
         &self.predicate
     }
 
+    ///
+    /// Set the value of this statement's predicate.
+    ///
+    pub fn set_predicate(&mut self, predicate: IRIRef) {
+        self.predicate = predicate;
+    }
+
     ///
     /// Return the object of this statement.
     ///
@@ -657,6 +671,13 @@ impl Statement {
         &self.object
     }
 
+    ///
+    /// Set the value of this statement's object.
+    ///
+    pub fn set_object(&mut self, object: ObjectNodeRef) {
+        self.object = object;
+    }
+
     ///
     /// RDF Reification is the process of turning a single statement into a set of statements, and
     /// more importantly giving an identity (in the form of a blank node) to the statement.
